import { DataSource } from '@angular/cdk/collections';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import { map, tap } from 'rxjs/operators';
import { merge, Observable, of as observableOf } from 'rxjs';
import { Account } from '../../core/account';


export class AccountListDataSource extends DataSource<Account> {
  private filterValue: string;

  constructor(private paginator: MatPaginator, private sort: MatSort, private filter: Observable<string>, public data: Account[]) {
    super();
    this.filter = filter.pipe(
      tap(x => this.filterValue = x)
    );
  }

  connect(): Observable<Account[]> {
    const dataMutations = [
      observableOf(this.data),
      this.filter,
      this.paginator.page,
      this.sort.sortChange
    ];

    return merge(...dataMutations).pipe(
      map((x: any) => {
        return this.getFilteredData([...this.data]);
      }),
      tap((x: Account[]) => this.paginator.length = x.length)
    ).pipe(
      map((x: any) => {
        return this.getPagedData(this.getSortedData(x));
      })
    );
  }

  disconnect() {
  }

  private getFilteredData(data: Account[]): Account[] {
    const filter = (this.filterValue === undefined) ? '' : this.filterValue;
    return filter.split(' ').reduce((p: Account[], c: string) => {
      return p.filter(x => {
          const accountString = (
            x.name + ' ' + x.type + ' ' + x.costCentre + (x.isActive ? ' active' : ' inactive')
          ).toLowerCase();
          return accountString.indexOf(c) !== -1;
        }
      );
    }, Object.assign([], data));
  }

  private getPagedData(data: Account[]) {
    const startIndex = this.paginator.pageIndex * this.paginator.pageSize;
    return data.splice(startIndex, this.paginator.pageSize);
  }

  private getSortedData(data: Account[]) {
    if (!this.sort.active || this.sort.direction === '') {
      return data;
    }

    return data.sort((a, b) => {
      const isAsc = this.sort.direction === 'asc';
      switch (this.sort.active) {
        case 'name':
          return compare(a.name, b.name, isAsc);
        case 'type':
          return compare(a.type, b.type, isAsc);
        case 'isActive':
          return compare(a.isActive, b.isActive, isAsc);
        case 'isReconcilable':
          return compare(a.isReconcilable, b.isReconcilable, isAsc);
        case 'costCentre':
          return compare(a.costCentre, b.costCentre, isAsc);
        case 'id':
          return compare(+a.id, +b.id, isAsc);
        default:
          return 0;
      }
    });
  }
}

/** Simple sort comparator for example ID/Name columns (for client-side sorting). */
function compare(a, b, isAsc) {
  return (a < b ? -1 : 1) * (isAsc ? 1 : -1);
}
