import {NgModule} from '@angular/core';
import {CommonModule} from '@angular/common';
import {RouterModule, Routes} from '@angular/router';

import {AccountListResolver} from './account-list-resolver.service';
import {AccountResolver} from './account-resolver.service';
import {AccountTypeResolver} from './account-type-resolver.service';
import {AccountDetailComponent} from './account-detail/account-detail.component';
import {AccountListComponent} from './account-list/account-list.component';

import {AuthGuard} from '../auth/auth-guard.service';
import {CostCentreListResolver} from '../cost-centre/cost-centre-list-resolver.service';

const accountRoutes: Routes = [
  {
    path: '',
    component: AccountListComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Accounts'
    },
    resolve: {
      list: AccountListResolver
    }
  },
  {
    path: 'new',
    component: AccountDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Accounts'
    },
    resolve: {
      item: AccountResolver,
      accountTypes: AccountTypeResolver,
      costCentres: CostCentreListResolver
    }
  },
  {
    path: ':id',
    component: AccountDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Accounts'
    },
    resolve: {
      item: AccountResolver,
      accountTypes: AccountTypeResolver,
      costCentres: CostCentreListResolver
    }
  }
];

@NgModule({
  imports: [
    CommonModule,
    RouterModule.forChild(accountRoutes)

  ],
  exports: [
    RouterModule
  ],
  providers: [
    AccountListResolver,
    AccountResolver
  ]
})
export class AccountRoutingModule {
}
