import {Component, OnInit, ViewChild} from '@angular/core';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import {BalanceSheetDataSource} from './balance-sheet-datasource';
import {BalanceSheet} from './balance-sheet';
import {ActivatedRoute, Router} from '@angular/router';
import * as moment from 'moment';
import {FormBuilder, FormGroup} from '@angular/forms';

@Component({
  selector: 'app-balance-sheet',
  templateUrl: './balance-sheet.component.html',
  styleUrls: ['./balance-sheet.component.css']
})
export class BalanceSheetComponent implements OnInit {
  @ViewChild(MatPaginator, { static: true }) paginator: MatPaginator;
  @ViewChild(MatSort, { static: true }) sort: MatSort;
  dataSource: BalanceSheetDataSource;
  form: FormGroup;
  info: BalanceSheet;
  /** Columns displayed in the table. Columns IDs can be added, removed, or reordered. */
  displayedColumns = ['group', 'name', 'subAmount', 'total'];

  constructor(private route: ActivatedRoute, private router: Router, private fb: FormBuilder) {
    this.createForm();
  }

  createForm() {
    this.form = this.fb.group({
      date: ''
    });
  }

  ngOnInit() {
    this.route.data
      .subscribe((data: { info: BalanceSheet }) => {
        this.info = data.info;
        this.form.setValue({
          date: moment(this.info.date, 'DD-MMM-YYYY').toDate()
        });
      });
    this.dataSource = new BalanceSheetDataSource(this.paginator, this.sort, this.info.body);
  }

  show() {
    const date = this.getDate();
    this.router.navigate(['balance-sheet', date]);
  }

  getDate(): string {
    const formModel = this.form.value;
    return  moment(formModel.date).format('DD-MMM-YYYY');
  }
}
