import {Injectable} from '@angular/core';
import {catchError} from 'rxjs/operators';
import {Observable} from 'rxjs/internal/Observable';
import {HttpClient, HttpHeaders} from '@angular/common/http';
import {BalanceSheet} from './balance-sheet';
import {ErrorLoggerService} from '../core/error-logger.service';

const httpOptions = {
  headers: new HttpHeaders({'Content-Type': 'application/json'})
};

const url = '/api/balance-sheet';
const serviceName = 'BalanceSheetService';

@Injectable({
  providedIn: 'root'
})
export class BalanceSheetService {

  constructor(private http: HttpClient, private log: ErrorLoggerService) {
  }

  list(date: string): Observable<BalanceSheet> {
    const listUrl = (date === null) ? url : `${url}/${date}`;
    return <Observable<BalanceSheet>>this.http.get<BalanceSheet>(listUrl)
      .pipe(
        catchError(this.log.handleError(serviceName, 'list'))
      );
  }

}
