import {Component, OnInit} from '@angular/core';
import {CashFlowDataSource} from './cash-flow-datasource';
import {CashFlow} from './cash-flow';
import {ActivatedRoute, Router} from '@angular/router';
import * as moment from 'moment';
import {FormBuilder, FormGroup} from '@angular/forms';

@Component({
  selector: 'app-cash-flow',
  templateUrl: './cash-flow.component.html',
  styleUrls: ['./cash-flow.component.css']
})
export class CashFlowComponent implements OnInit {
  dataSource: CashFlowDataSource;
  form: FormGroup;
  info: CashFlow;
  /** Columns displayed in the table. Columns IDs can be added, removed, or reordered. */
  displayedColumns = ['name', 'amount'];

  constructor(private route: ActivatedRoute, private router: Router, private fb: FormBuilder) {
    this.createForm();
  }

  createForm() {
    this.form = this.fb.group({
      startDate: '',
      finishDate: ''
    });
  }

  ngOnInit() {
    this.route.data
      .subscribe((data: { info: CashFlow }) => {
        this.info = data.info;
        this.form.setValue({
          startDate: moment(this.info.startDate, 'DD-MMM-YYYY').toDate(),
          finishDate: moment(this.info.finishDate, 'DD-MMM-YYYY').toDate()
        });
        this.dataSource = new CashFlowDataSource(CashFlow.Data(this.info));
      });
  }

  show() {
    const info = this.getInfo();
    this.router.navigate(['cash-flow'], {
      queryParams: {
        startDate: info.startDate,
        finishDate: info.finishDate
      }
    });
  }

  getInfo(): CashFlow {
    const formModel = this.form.value;

    return {
      startDate: moment(formModel.startDate).format('DD-MMM-YYYY'),
      finishDate: moment(formModel.finishDate).format('DD-MMM-YYYY')
    };
  }
}
