import {AfterViewInit, Component, ElementRef, OnInit, ViewChild} from '@angular/core';

import {ClientService} from '../client.service';
import {Client} from '../client';
import {ActivatedRoute, Router} from '@angular/router';
import {ToasterService} from '../../core/toaster.service';
import {ConfirmDialogComponent} from '../../shared/confirm-dialog/confirm-dialog.component';
import { MatDialog } from '@angular/material/dialog';
import {FormBuilder, FormGroup} from '@angular/forms';

@Component({
  selector: 'app-client-detail',
  templateUrl: './client-detail.component.html',
  styleUrls: ['./client-detail.component.css']
})
export class ClientDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement: ElementRef;
  form: FormGroup;
  item: Client;

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private fb: FormBuilder,
    private toaster: ToasterService,
    private ser: ClientService
  ) {
    this.createForm();
  }

  createForm() {
    this.form = this.fb.group({
      code: {value: '', disabled: true},
      name: '',
      enabled: false,
      otp: ''
    });
  }

  ngOnInit() {
    this.route.data
      .subscribe((data: { item: Client }) => {
        this.showItem(data.item);
      });
  }

  showItem(item: Client) {
    this.item = item;
    this.form.setValue({
      code: this.item.code || '(Auto)',
      name: this.item.name,
      enabled: this.item.enabled,
      otp: this.item.otp
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      this.nameElement.nativeElement.focus();
    }, 0);
  }

  save() {
    this.ser.update(this.getItem())
      .subscribe(
        (result) => {
          this.toaster.show('Success', '');
          this.router.navigateByUrl('/clients');
        },
        (error) => {
          this.toaster.show('Danger', error);
        }
      );
  }

  delete() {
    this.ser.delete(this.item.id)
      .subscribe(
        (result) => {
          this.toaster.show('Success', '');
          this.router.navigateByUrl('/clients');
        },
        (error) => {
          this.toaster.show('Danger', error);
        }
      );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: {title: 'Delete Client?', content: 'Are you sure? This cannot be undone.'}
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): Client {
    const formModel = this.form.value;
    this.item.name = formModel.name;
    this.item.enabled = formModel.enabled;
    this.item.otp = formModel.otp;
    return this.item;
  }
}
