import {Injectable} from '@angular/core';
import {HttpClient, HttpHeaders, HttpParams} from '@angular/common/http';
import {ErrorLoggerService} from '../core/error-logger.service';
import {catchError} from 'rxjs/operators';
import {Observable} from 'rxjs/internal/Observable';
import {Client} from './client';

const httpOptions = {
  headers: new HttpHeaders({'Content-Type': 'application/json'})
};
const url = '/api/clients';
const serviceName = 'ClientService';

@Injectable({
  providedIn: 'root'
})
export class ClientService {
  constructor(private http: HttpClient, private log: ErrorLoggerService) {
  }

  get(id: string): Observable<Client> {
    const getUrl: string = (id === null) ? url : `${url}/${id}`;
    return <Observable<Client>>this.http.get<Client>(getUrl)
      .pipe(
        catchError(this.log.handleError(serviceName, `get id=${id}`))
      );
  }

  list(): Observable<Client[]> {
    return <Observable<Client[]>>this.http.get<Client[]>(`${url}/list`)
      .pipe(
        catchError(this.log.handleError(serviceName, 'list'))
      );
  }

  update(client: Client): Observable<Client> {
    return <Observable<Client>>this.http.put<Client>(`${url}/${client.id}`, client, httpOptions)
      .pipe(
        catchError(this.log.handleError(serviceName, 'update'))
      );
  }

  delete(id: string): Observable<Client> {
    return <Observable<Client>>this.http.delete<Client>(`${url}/${id}`, httpOptions)
      .pipe(
        catchError(this.log.handleError(serviceName, 'delete'))
      );
  }
}
