import {Component, OnInit, ViewChild} from '@angular/core';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import {ClosingStockDataSource} from './closing-stock-datasource';
import {ClosingStock} from './closing-stock';
import {ActivatedRoute, Router} from '@angular/router';
import * as moment from 'moment';
import {FormBuilder, FormGroup} from '@angular/forms';
import {ToCsvService} from '../shared/to-csv.service';

@Component({
  selector: 'app-closing-stock',
  templateUrl: './closing-stock.component.html',
  styleUrls: ['./closing-stock.component.css']
})
export class ClosingStockComponent implements OnInit {
  @ViewChild(MatPaginator, { static: true }) paginator: MatPaginator;
  @ViewChild(MatSort, { static: true }) sort: MatSort;
  dataSource: ClosingStockDataSource;
  form: FormGroup;
  info: ClosingStock;
  /** Columns displayed in the table. Columns IDs can be added, removed, or reordered. */
  displayedColumns = ['product', 'group', 'quantity', 'amount'];

  constructor(private route: ActivatedRoute, private router: Router, private fb: FormBuilder, private toCsv: ToCsvService) {
    this.createForm();
  }

  createForm() {
    this.form = this.fb.group({
      date: ''
    });
  }

  ngOnInit() {
    this.route.data
      .subscribe((data: { info: ClosingStock }) => {
        this.info = data.info;
        this.form.setValue({
          date: moment(this.info.date, 'DD-MMM-YYYY').toDate()
        });
      });
    this.dataSource = new ClosingStockDataSource(this.paginator, this.sort, this.info.body);
  }

  show() {
    const info = this.getInfo();
    this.router.navigate(['closing-stock', info.date]);
  }

  getInfo(): ClosingStock {
    const formModel = this.form.value;

    return {
      date: moment(formModel.date).format('DD-MMM-YYYY')
    };
  }

  exportCsv() {
    const headers = {
      Product: 'product',
      Group: 'group',
      Quantity: 'quantity',
      Amount: 'amount'
    };

    const csvData = new Blob([this.toCsv.toCsv(headers, this.dataSource.data)], {type: 'text/csv;charset=utf-8;'});
    const link = document.createElement('a');
    link.href = window.URL.createObjectURL(csvData);
    link.setAttribute('download', 'closing-stock.csv');
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
  }
}
