import {Account} from './account';
import {User} from './user';
import {CostCentre} from './cost-centre';
import {Product} from './product';
import {Employee} from "../employee/employee";

export class Voucher {
  id: string;
  date: string;
  type: string;
  posted: boolean;
  narration: string;
  incentive?: number;
  vendor?: Account;
  source?: CostCentre;
  destination?: CostCentre;
  journals: Journal[];
  inventories: Inventory[];
  employeeBenefits: EmployeeBenefit[];
  incentives: Incentive[];
  files: DbFile[];
  creationDate: string;
  lastEditDate: string;
  user: User;
  isStarred: boolean;
  poster: string;
  reconcileDate: string;
}

export class Journal {
  id: string;
  debit: number;
  amount: number;
  account: Account;
  costCentre: CostCentre;

  public constructor(init?: Partial<Journal>) {
    Object.assign(this, init);
  }
}

export class EmployeeBenefit {
  grossSalary: number;
  daysWorked: number;
  esiEmployee: number;
  pfEmployee: number;
  esiEmployer: number;
  pfEmployer: number;
  employee: Employee;
}

export class Incentive {
  id: string;
  name: string;
  designation: string;
  department: string;
  daysWorked: number;
  points: number;

}

export class Inventory {
  id: string;
  quantity: number;
  rate: number;
  tax: number;
  discount: number;
  amount: number;
  product: Product;
  batch: Batch;
}

export class Batch {
  id: string;
  name: string;
  quantityRemaining: number;
  tax: number;
  discount: number;
  rate: number;
  product: Product;
}

export class DbFile {
  id: string;
  resized: string;
  thumbnail: string;
}
