import {AfterViewInit, Component, ElementRef, OnInit, ViewChild} from '@angular/core';

import {CostCentreService} from '../cost-centre.service';
import {CostCentre} from '../../core/cost-centre';
import {ActivatedRoute, Router} from '@angular/router';
import {ToasterService} from '../../core/toaster.service';
import {FormBuilder, FormGroup} from '@angular/forms';

@Component({
  selector: 'app-cost-centre-detail',
  templateUrl: './cost-centre-detail.component.html',
  styleUrls: ['./cost-centre-detail.component.css']
})
export class CostCentreDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement: ElementRef;
  form: FormGroup;
  item: CostCentre;

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private fb: FormBuilder,
    private toaster: ToasterService,
    private ser: CostCentreService
  ) {
    this.createForm();
  }

  createForm() {
    this.form = this.fb.group({
      name: ''
    });
  }

  ngOnInit() {
    this.route.data
      .subscribe((data: { item: CostCentre }) => {
        this.showItem(data.item);
      });
  }

  showItem(item: CostCentre) {
    this.item = item;
    this.form.setValue({
      name: this.item.name,
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      this.nameElement.nativeElement.focus();
    }, 0);
  }

  save() {
    this.ser.saveOrUpdate(this.getItem())
      .subscribe(
        (result) => {
          this.toaster.show('Success', '');
          this.router.navigateByUrl('/cost-centres');
        },
        (error) => {
          this.toaster.show('Danger', error);
        }
      );
  }

  getItem(): CostCentre {
    const formModel = this.form.value;
    this.item.name = formModel.name;
    return this.item;
  }
}
