import {Injectable} from '@angular/core';
import {HttpClient, HttpHeaders, HttpParams} from '@angular/common/http';
import {ErrorLoggerService} from '../core/error-logger.service';
import {catchError} from 'rxjs/operators';
import {Observable} from 'rxjs/internal/Observable';
import {CostCentre} from '../core/cost-centre';

const httpOptions = {
  headers: new HttpHeaders({'Content-Type': 'application/json'})
};
const url = '/api/cost-centres';
const serviceName = 'CostCentreService';

@Injectable({
  providedIn: 'root'
})
export class CostCentreService {
  constructor(private http: HttpClient, private log: ErrorLoggerService) {
  }

  get(id: string): Observable<CostCentre> {
    const getUrl: string = (id === null) ? `${url}` : `${url}/${id}`;
    return <Observable<CostCentre>>this.http.get<CostCentre>(getUrl)
      .pipe(
        catchError(this.log.handleError(serviceName, `get id=${id}`))
      );
  }

  list(): Observable<CostCentre[]> {
    return <Observable<CostCentre[]>>this.http.get<CostCentre[]>(`${url}/list`)
      .pipe(
        catchError(this.log.handleError(serviceName, 'list'))
      );
  }

  save(costCentre: CostCentre): Observable<CostCentre> {
    return <Observable<CostCentre>>this.http.post<CostCentre>(`${url}`, costCentre, httpOptions)
      .pipe(
        catchError(this.log.handleError(serviceName, 'save'))
      );
  }

  update(costCentre: CostCentre): Observable<CostCentre> {
    return <Observable<CostCentre>>this.http.put<CostCentre>(`${url}/${costCentre.id}`, costCentre, httpOptions)
      .pipe(
        catchError(this.log.handleError(serviceName, 'update'))
      );
  }

  saveOrUpdate(costCentre: CostCentre): Observable<CostCentre> {
    if (!costCentre.id) {
      return this.save(costCentre);
    } else {
      return this.update(costCentre);
    }
  }

  delete(id: string): Observable<CostCentre> {
    return <Observable<CostCentre>>this.http.delete<CostCentre>(`${url}/${id}`, httpOptions)
      .pipe(
        catchError(this.log.handleError(serviceName, 'delete'))
      );
  }
}
