import {Injectable} from '@angular/core';
import {catchError} from 'rxjs/operators';
import {Observable} from 'rxjs/internal/Observable';
import {HttpClient, HttpHeaders, HttpParams} from '@angular/common/http';
import {Daybook} from './daybook';
import {ErrorLoggerService} from '../core/error-logger.service';

const httpOptions = {
  headers: new HttpHeaders({'Content-Type': 'application/json'})
};

const url = '/api/daybook';
const serviceName = 'DaybookService';

@Injectable({
  providedIn: 'root'
})
export class DaybookService {

  constructor(private http: HttpClient, private log: ErrorLoggerService) {
  }

  list(startDate: string, finishDate): Observable<Daybook> {
    startDate = startDate ? `/${startDate}` : '';
    finishDate = finishDate ? `/${finishDate}` : '';
    return <Observable<Daybook>>this.http.get<Daybook>(`${url}${startDate}${finishDate}`)
      .pipe(
        catchError(this.log.handleError(serviceName, 'list'))
      );
  }

}
