import {Injectable} from '@angular/core';
import {Observable} from 'rxjs/internal/Observable';
import {catchError} from 'rxjs/operators';
import {HttpClient, HttpHeaders, HttpParams} from '@angular/common/http';
import {EmployeeAttendance} from './employee-attendance';
import {ErrorLoggerService} from '../core/error-logger.service';

const httpOptions = {
  headers: new HttpHeaders({'Content-Type': 'application/json'})
};

const url = '/api/employee-attendance';
const serviceName = 'EmployeeAttendanceService';

@Injectable({providedIn: 'root'})
export class EmployeeAttendanceService {

  constructor(private http: HttpClient, private log: ErrorLoggerService) {
  }

  get(id: string, startDate: string, finishDate: string): Observable<EmployeeAttendance> {
    const getUrl: string = (id === null) ? url : `${url}/${id}`;
    const options = {params: new HttpParams()};
    if (startDate !== null) {
      options.params = options.params.set('s', startDate);
    }
    if (finishDate !== null) {
      options.params = options.params.set('f', finishDate);
    }
    return <Observable<EmployeeAttendance>>this.http.get<EmployeeAttendance>(getUrl, options)
      .pipe(
        catchError(this.log.handleError(serviceName, `get id=${id}`))
      );
  }

  save(employeeAttendance: EmployeeAttendance): Observable<EmployeeAttendance> {
    const id = employeeAttendance.employee.id;
    return <Observable<EmployeeAttendance>>this.http.post<EmployeeAttendance>(`${url}/${id}`, employeeAttendance, httpOptions)
      .pipe(
        catchError(this.log.handleError(serviceName, 'save'))
      );
  }
}
