import {Injectable} from '@angular/core';
import {Observable} from 'rxjs/internal/Observable';
import {catchError} from 'rxjs/operators';
import {HttpClient, HttpHeaders} from '@angular/common/http';
import {ErrorLoggerService} from '../core/error-logger.service';

const httpOptions = {
  headers: new HttpHeaders({'Content-Type': 'application/json'})
};

const serviceName = 'EmployeeFunctionsService';

@Injectable({providedIn: 'root'})
export class EmployeeFunctionsService {

  constructor(private http: HttpClient, private log: ErrorLoggerService) {
  }

  creditSalary(month: string): Observable<boolean> {
    const url = '/api/credit-salary';
    return <Observable<boolean>>this.http.post<boolean>(url, {month: month})
      .pipe(
        catchError(this.log.handleError(serviceName, `creditSalary`))
      );
  }

  uploadFingerprints(fingerprintFile: File): Observable<boolean> {
    const url = '/api/fingerprint';
    const fd = new FormData();
    fd.append('uploadedFile', fingerprintFile);
    return <Observable<boolean>>this.http.post<boolean>(url, fd)
      .pipe(
        catchError(this.log.handleError(serviceName, `uploadFingerprints`))
      );
  }

}
