import { DataSource } from '@angular/cdk/collections';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import { map, tap } from 'rxjs/operators';
import { merge, Observable, of as observableOf } from 'rxjs';
import { Employee } from '../employee';


export class EmployeeListDataSource extends DataSource<Employee> {
  private filterValue: string;

  constructor(private paginator: MatPaginator, private sort: MatSort, private filter: Observable<string>, public data: Employee[]) {
    super();
    this.filter = filter.pipe(
      tap(x => this.filterValue = x)
    );
  }

  connect(): Observable<Employee[]> {
    const dataMutations = [
      observableOf(this.data),
      this.filter,
      this.paginator.page,
      this.sort.sortChange
    ];

    return merge(...dataMutations).pipe(
      map((x: any) => {
        return this.getFilteredData([...this.data]);
      }),
      tap((x: Employee[]) => this.paginator.length = x.length)
    ).pipe(
      map((x: any) => {
        return this.getPagedData(this.getSortedData(x));
      })
    );
  }

  disconnect() {
  }

  private getFilteredData(data: Employee[]): Employee[] {
    const filter = (this.filterValue === undefined) ? '' : this.filterValue;
    return filter.split(' ').reduce((p: Employee[], c: string) => {
      return p.filter(x => {
          const employeeString = (
            x.code + ' ' + x.name + ' ' + x.designation + ' ' + x.costCentre + (x.isActive ? ' active' : ' inactive')
          ).toLowerCase();
          return employeeString.indexOf(c) !== -1;
        }
      );
    }, Object.assign([], data));
  }

  private getPagedData(data: Employee[]) {
    const startIndex = this.paginator.pageIndex * this.paginator.pageSize;
    return data.splice(startIndex, this.paginator.pageSize);
  }

  private getSortedData(data: Employee[]) {
    if (!this.sort.active || this.sort.direction === '') {
      return data;
    }

    return data.sort((a, b) => {
      const isAsc = this.sort.direction === 'asc';
      switch (this.sort.active) {
        case 'code':
          return compare(+a.code, +b.code, isAsc);
        case 'name':
          return compare(a.name, b.name, isAsc);
        case 'designation':
          return compare(a.designation, b.designation, isAsc);
        case 'salary':
          return compare(a.salary, b.salary, isAsc);
        case 'points':
          return compare(a.points, b.points, isAsc);
        case 'department':
          return compare(a.costCentre, b.costCentre, isAsc);
        case 'joiningDate':
          return compare(a.joiningDate, b.joiningDate, isAsc);
        case 'leavingDate':
          return compare(a.leavingDate, b.leavingDate, isAsc);
        default:
          return 0;
      }
    });
  }
}

/** Simple sort comparator for example ID/Name columns (for client-side sorting). */
function compare(a, b, isAsc) {
  return (a < b ? -1 : 1) * (isAsc ? 1 : -1);
}
