import {Injectable} from '@angular/core';
import {catchError} from 'rxjs/operators';
import {Observable} from 'rxjs/internal/Observable';
import {HttpClient, HttpHeaders, HttpParams} from '@angular/common/http';
import {Ledger} from './ledger';
import {ErrorLoggerService} from '../core/error-logger.service';

const httpOptions = {
  headers: new HttpHeaders({'Content-Type': 'application/json'})
};

const url = '/api/ledger';
const serviceName = 'LedgerService';

@Injectable({
  providedIn: 'root'
})
export class LedgerService {

  constructor(private http: HttpClient, private log: ErrorLoggerService) {
  }

  list(id: string, startDate: string, finishDate): Observable<Ledger> {
    const listUrl = (id === null) ? url : `${url}/${id}`;
    const options = {params: new HttpParams()};
    if (startDate !== null) {
      options.params = options.params.set('s', startDate);
    }
    if (finishDate !== null) {
      options.params = options.params.set('f', finishDate);
    }
    return <Observable<Ledger>>this.http.get<Ledger>(listUrl, options)
      .pipe(
        catchError(this.log.handleError(serviceName, 'list'))
      );
  }

}
