import {Injectable} from '@angular/core';
import {catchError} from 'rxjs/operators';
import {Observable} from 'rxjs/internal/Observable';
import {HttpClient, HttpHeaders, HttpParams} from '@angular/common/http';
import {ProductLedger} from './product-ledger';
import {ErrorLoggerService} from '../core/error-logger.service';

const httpOptions = {
  headers: new HttpHeaders({'Content-Type': 'application/json'})
};

const url = '/api/product-ledger';
const serviceName = 'ProductLedgerService';

@Injectable({
  providedIn: 'root'
})
export class ProductLedgerService {

  constructor(private http: HttpClient, private log: ErrorLoggerService) {
  }

  list(id: string, startDate: string, finishDate): Observable<ProductLedger> {
    const listUrl = (id === null) ? url : `${url}/${id}`;
    const options = {params: new HttpParams()};
    if (startDate !== null) {
      options.params = options.params.set('s', startDate);
    }
    if (finishDate !== null) {
      options.params = options.params.set('f', finishDate);
    }
    return <Observable<ProductLedger>>this.http.get<ProductLedger>(listUrl, options)
      .pipe(
        catchError(this.log.handleError(serviceName, 'list'))
      );
  }

}
