import {NgModule} from '@angular/core';
import {CommonModule} from '@angular/common';
import {RouterModule, Routes} from '@angular/router';

import {ProductListResolver} from './product-list-resolver.service';
import {ProductResolver} from './product-resolver.service';
import {ProductDetailComponent} from './product-detail/product-detail.component';
import {ProductListComponent} from './product-list/product-list.component';

import {AuthGuard} from '../auth/auth-guard.service';
import {ProductGroupListResolver} from '../product-group/product-group-list-resolver.service';

const productRoutes: Routes = [
  {
    path: '',
    component: ProductListComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Products'
    },
    resolve: {
      list: ProductListResolver
    }
  },
  {
    path: 'new',
    component: ProductDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Products'
    },
    resolve: {
      item: ProductResolver,
      productGroups: ProductGroupListResolver
    }
  },
  {
    path: ':id',
    component: ProductDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Products'
    },
    resolve: {
      item: ProductResolver,
      productGroups: ProductGroupListResolver
    }
  }
];

@NgModule({
  imports: [
    CommonModule,
    RouterModule.forChild(productRoutes)

  ],
  exports: [
    RouterModule
  ],
  providers: [
    ProductListResolver,
    ProductResolver
  ]
})
export class ProductRoutingModule {
}
