import {Component, OnInit, ViewChild} from '@angular/core';
import {FormBuilder, FormGroup} from '@angular/forms';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import {ActivatedRoute, Router} from '@angular/router';
import * as moment from 'moment';
import {PurchaseEntriesDataSource} from './purchase-entries-datasource';
import {PurchaseEntries} from './purchase-entries';
import {map} from 'rxjs/operators';

@Component({
  selector: 'app-purchase-entries',
  templateUrl: './purchase-entries.component.html',
  styleUrls: ['./purchase-entries.component.css']
})
export class PurchaseEntriesComponent implements OnInit {
  @ViewChild(MatPaginator, { static: true }) paginator: MatPaginator;
  @ViewChild(MatSort, { static: true }) sort: MatSort;
  dataSource: PurchaseEntriesDataSource;
  form: FormGroup;
  info: PurchaseEntries;
  selectedRowId: string;
  /** Columns displayed in the table. Columns IDs can be added, removed, or reordered. */
  displayedColumns = ['date', 'supplier', 'product', 'quantity', 'rate', 'tax', 'discount', 'amount'];

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private fb: FormBuilder
  ) {
    this.createForm();
  }

  ngOnInit() {
    this.route.data.subscribe((data: { info: PurchaseEntries }) => {
        this.info = data.info;
        this.form.setValue({
          startDate: moment(this.info.startDate, 'DD-MMM-YYYY').toDate(),
          finishDate: moment(this.info.finishDate, 'DD-MMM-YYYY').toDate()
        });
        this.dataSource = new PurchaseEntriesDataSource(this.paginator, this.sort, this.info.body);
      });
  }

  show() {
    const l = this.prepareSubmit();
    this.router.navigate(['purchase-entries'], {
      queryParams: {
        startDate: l.startDate,
        finishDate: l.finishDate
      }
    });
  }

  createForm() {
    this.form = this.fb.group({
      startDate: '',
      finishDate: '',
    });
  }

  prepareSubmit(): PurchaseEntries {
    const formModel = this.form.value;

    return {
      startDate: moment(formModel.startDate).format('DD-MMM-YYYY'),
      finishDate: moment(formModel.finishDate).format('DD-MMM-YYYY'),
      body: []
    };
  }
}
