import {Injectable} from '@angular/core';
import {catchError} from 'rxjs/operators';
import {Observable} from 'rxjs/internal/Observable';
import {HttpClient, HttpHeaders, HttpParams} from '@angular/common/http';
import {Purchases} from './purchases';
import {ErrorLoggerService} from '../core/error-logger.service';

const httpOptions = {
  headers: new HttpHeaders({'Content-Type': 'application/json'})
};

const url = '/api/purchases';
const serviceName = 'PurchasesService';

@Injectable({
  providedIn: 'root'
})
export class PurchasesService {

  constructor(private http: HttpClient, private log: ErrorLoggerService) {
  }

  list(startDate: string, finishDate): Observable<Purchases> {
    startDate = startDate ? `/${startDate}` : '';
    finishDate = finishDate ? `/${finishDate}` : '';
    return <Observable<Purchases>>this.http.get<Purchases>(`${url}${startDate}${finishDate}`)
      .pipe(
        catchError(this.log.handleError(serviceName, 'list'))
      );
  }

}
