import {Component, OnInit, ViewChild} from '@angular/core';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort } from '@angular/material/sort';
import {TrialBalanceDataSource} from './trial-balance-datasource';
import {TrialBalance} from './trial-balance';
import {ActivatedRoute, Router} from '@angular/router';
import * as moment from 'moment';
import {FormBuilder, FormGroup} from '@angular/forms';

@Component({
  selector: 'app-trial-balance',
  templateUrl: './trial-balance.component.html',
  styleUrls: ['./trial-balance.component.css']
})
export class TrialBalanceComponent implements OnInit {
  @ViewChild(MatPaginator, { static: true }) paginator: MatPaginator;
  @ViewChild(MatSort, { static: true }) sort: MatSort;
  dataSource: TrialBalanceDataSource;
  form: FormGroup;
  info: TrialBalance;
  /** Columns displayed in the table. Columns IDs can be added, removed, or reordered. */
  displayedColumns = ['type', 'name', 'debit', 'credit'];

  constructor(private route: ActivatedRoute, private router: Router, private fb: FormBuilder) {
    this.createForm();
  }

  createForm() {
    this.form = this.fb.group({
      date: ''
    });
  }

  ngOnInit() {
    this.route.data
      .subscribe((data: { info: TrialBalance }) => {
        this.info = data.info;
        this.form.setValue({
          date: moment(this.info.date, 'DD-MMM-YYYY').toDate()
        });
      });
    this.dataSource = new TrialBalanceDataSource(this.paginator, this.sort, this.info.body);
  }

  show() {
    const info = this.getInfo();
    this.router.navigate(['trial-balance', info.date]);
  }

  getInfo(): TrialBalance {
    const formModel = this.form.value;

    return {
      date: moment(formModel.date).format('DD-MMM-YYYY')
    };
  }
}
