import {Injectable} from '@angular/core';
import {catchError} from 'rxjs/operators';
import {Observable} from 'rxjs/internal/Observable';
import {HttpClient, HttpHeaders} from '@angular/common/http';
import {TrialBalance} from './trial-balance';
import {ErrorLoggerService} from '../core/error-logger.service';

const httpOptions = {
  headers: new HttpHeaders({'Content-Type': 'application/json'})
};

const url = '/api/trial-balance';
const serviceName = 'TrialBalanceService';

@Injectable({
  providedIn: 'root'
})
export class TrialBalanceService {

  constructor(private http: HttpClient, private log: ErrorLoggerService) {
  }

  list(date: string): Observable<TrialBalance> {
    const listUrl = (date === null) ? url : `${url}/${date}`;
    return <Observable<TrialBalance>>this.http.get<TrialBalance>(listUrl)
      .pipe(
        catchError(this.log.handleError(serviceName, 'list'))
      );
  }

}
