import {NgModule} from '@angular/core';
import {CommonModule} from '@angular/common';
import {RouterModule, Routes} from '@angular/router';
import {UserListResolver} from './user-list-resolver.service';
import {UserResolver} from './user-resolver.service';
import {UserListComponent} from './user-list/user-list.component';
import {UserDetailComponent} from './user-detail/user-detail.component';
import {AuthGuard} from '../auth/auth-guard.service';

const userRoutes: Routes = [
  {
    path: '',
    component: UserListComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Users'
    },
    resolve: {
      list: UserListResolver
    }
  },
  {
    path: 'new',
    component: UserDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Users'
    },
    resolve: {
      item: UserResolver,
    }
  },
  {
    path: ':id',
    component: UserDetailComponent,
    canActivate: [AuthGuard],
    resolve: {
      item: UserResolver
    }
  }
];

@NgModule({
  imports: [
    CommonModule,
    RouterModule.forChild(userRoutes)

  ],
  exports: [
    RouterModule
  ],
  providers: [
    UserListResolver,
    UserResolver
  ]
})
export class UserRoutingModule {
}
